package Sah::PSchemas::Perl;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-01-20'; # DATE
our $DIST = 'Sah-PSchemas-Perl'; # DIST
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: Parameterized schemas related to Perl

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::PSchemas::Perl - Parameterized schemas related to Perl

=head1 VERSION

This document describes version 0.004 of Sah::PSchemas::Perl (from Perl distribution Sah-PSchemas-Perl), released on 2021-01-20.

=head1 DESCRIPTION

B<EXPERIMENTAL.>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-PSchemas-Perl>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-PSchemas-Perl>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Sah-PSchemas-Perl/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

C<Sah::Schemas::Perl>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
